@@ -12,7 +12,7 @@ from distutils.spawn import find_executable
 matam_16s_usage = '''
 =================================== matam_16s example commands ===================================
 
-MarkerMAG matam_16s -p Test -r1 R1.fasta -r2 R2.fasta -t 12 -force -d path/to/SILVA_128_SSURef_NR95
+MarkerMAG matam_16s -p Test -r1 R1.fasta -r2 R2.fasta -t 12 -force -d path/to/SILVA_138_SSURef_NR99
 
 ==================================================================================================
 '''
@@ -234,7 +234,7 @@ def matam_16s(args):
     uclust_iden_cutoff              = args['i']
     num_threads                     = args['t']
     force_overwrite                 = args['force']
-    matam_assembly_script           = args['matam_assembly']
+    matam_assembly_script           = args['matam']
     usearch_exe                     = args['usearch']
     seqtk_exe                       = args['seqtk']
     keep_quiet                      = args['quiet']
@@ -378,14 +378,13 @@ if __name__ == '__main__':
     matam_16s_parser.add_argument('-r16s',           required=False, default=None,                                      help='extracted 16S reads')
     matam_16s_parser.add_argument('-pct',            required=True,  type=str, default='1,5,10,25,50,75,100',           help='subsample percentage, must be integer, between 1-100, deafault: 1,5,10,25,50,75,100')
     matam_16s_parser.add_argument('-d',              required=False, type=str,                                          help='MATAM ref db, same as "-d" in Matam')
-    matam_16s_parser.add_argument('-i',              required=False, type=float, default=0.995,                         help='cluster identity cutoff (0-1), default: 0.995')
+    matam_16s_parser.add_argument('-i',              required=False, type=float, default=0.999,                         help='cluster identity cutoff (0-1), default: 0.999')
     matam_16s_parser.add_argument('-t',              required=False, type=int, default=1,                               help='number of threads, default: 1')
     matam_16s_parser.add_argument('-force',          required=False, action="store_true",                               help='force overwrite existing results')
     matam_16s_parser.add_argument('-quiet',          required=False, action="store_true",                               help='not report progress')
-    matam_16s_parser.add_argument('-matam_assembly', required=False, type=str, default='matam_assembly.py',             help='path to matam_assembly.py, default: matam_assembly.py')
+    matam_16s_parser.add_argument('-matam',          required=False, type=str, default='matam_assembly.py',             help='path to matam_assembly.py, default: matam_assembly.py')
     matam_16s_parser.add_argument('-seqtk',          required=False, type=str, default='seqtk',                         help='path to seqtk executable file, default: seqtk')
     matam_16s_parser.add_argument('-usearch',        required=False, type=str, default='usearch',                       help='path to usearch executable file, default: usearch')
 
     args = vars(matam_16s_parser.parse_args())
     matam_16s(args)
-
